@@ -1,3 +1,4 @@
+import inspect
 import shutil
 import tempfile
 import itertools
@@ -39,6 +40,21 @@ class SphinxUI(object):
     def warn(self, s):
         self.app.warn(s.strip('\n'))
 
+    def config(self, section, name, default=None, untrusted=False):
+        return default
+    configpath = confibool = configint = configbytes = configlist = config
+
+mpm_spec = inspect.getargspec(mercurial.patch.makepatchmeta)
+if len(mpm_spec.args) == 5:
+    # pre-3.4 mercurial
+    def makepatchmeta(backend, afile_orig, bfile_orig, hunk, strip):
+        return mercurial.patch.makepatchmeta(
+            backend, afile_orig, bfile_orig, hunk, strip)
+else:
+    # post-3.4, added required ``prefix``
+    def makepatchmeta(backend, afile_orig, bfile_orig, hunk, strip):
+        return mercurial.patch.makepatchmeta(
+            backend, afile_orig, bfile_orig, hunk, strip, '')
 
 class Series(object):
     """ Iterator on a sequence of patches, handles applying the patches to a
@@ -84,7 +100,7 @@ class Series(object):
                 if event == 'file':
                     fromfile, tofile, first_hunk, gp = values
                     if not gp:
-                        gp = mercurial.patch.makepatchmeta(
+                        gp = makepatchmeta(
                             patchbackend, fromfile, tofile, first_hunk,
                             # default strip value for applydiff
                             strip=1)
